#
# Conditional build:
%bcond_without	apidocs		# don't build API documentation
%bcond_without	static_libs	# don't build static libraries

Summary:	Wayland - protocol for a compositor to talk to its clients
Summary(pl.UTF-8):	Wayland - protokół między serwerem składającym a klientami
Name:		wayland
Version:	1.14.0
Release:	1
License:	MIT
Group:		Libraries
Source0:	https://wayland.freedesktop.org/releases/%{name}-%{version}.tar.xz
# Source0-md5:	0235f6075c32c3be61cff94fa0b9f108
Patch0:		%{name}-missing.patch
Patch1:		%{name}-man.patch
URL:		https://wayland.freedesktop.org/
BuildRequires:	autoconf >= 2.64
BuildRequires:	automake >= 1:1.11
BuildRequires:	expat-devel >= 1.95
BuildRequires:	libffi-devel >= 3
BuildRequires:	libtool >= 2:2.2
# for DTD valudation
BuildRequires:	libxml2-devel >= 2.0
BuildRequires:	pkgconfig
%if %{with apidocs}
BuildRequires:	docbook-style-xsl-nons
BuildRequires:	doxygen >= 1.6.0
BuildRequires:	graphviz >= 2.26.0
BuildRequires:	libxslt-progs
BuildRequires:	xmlto
%endif
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
Wayland is a project to define a protocol for a compositor to talk to
its clients as well as a library implementation of the protocol. The
compositor can be a standalone display server running on Linux kernel
modesetting and evdev input devices, an X application, or a Wayland
client itself. The clients can be traditional applications, X servers
(rootless or fullscreen) or other display servers.

%description -l pl.UTF-8
Wayland to projekt definiujący protokół między serwerem składającym a
klientami, a także biblioteki implementujące ten protokół. Serwer
składający może być samodzielnym serwerem wyświetlającym działającym
na linuksowym kernel modesetting oraz urządzeniach wejściowych evdev,
aplikacją X lub klientem Wayland. Klientami mogą być tradycyjne
aplikacje, serwery X (rootless lub pełnoekranowe) lub inne serwery
wyświetlające.

%package devel
Summary:	Header files for Wayland libraries
Summary(pl.UTF-8):	Pliki nagłówkowe bibliotek Wayland
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	libffi-devel

%description devel
Header files for Wayland libraries.

%description devel -l pl.UTF-8
Pliki nagłówkowe bibliotek Wayland.

%package static
Summary:	Static Wayland libraries
Summary(pl.UTF-8):	Statyczne biblioteki Wayland
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static Wayland libraries.

%description static -l pl.UTF-8
Statyczne biblioteki Wayland.

%package apidocs
Summary:	Wayland API and protocol documentation
Summary(pl.UTF-8):	Dokumentacja API biblioteki oraz protokołu Wayland
Group:		Documentation
%if "%{_rpmversion}" >= "5"
BuildArch:	noarch
%endif

%description apidocs
Wayland API and protocol documentation.

%description apidocs -l pl.UTF-8
Dokumentacja API biblioteki oraz protokołu Wayland.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

# force regeneration (.so link is broken, double man3/)
%{__rm} doc/man/*.3

%build
%{__libtoolize}
%{__aclocal} -I m4
%{__autoconf}
%{__autoheader}
%{__automake}
%configure \
	%{!?with_apidocs:--disable-documentation} \
	--disable-silent-rules \
	%{!?with_static_libs:--disable-static}

%{__make}

%install
rm -rf $RPM_BUILD_ROOT

%{__make} install \
	DESTDIR=$RPM_BUILD_ROOT

%if %{with apidocs}
# referenced by some installed wl_*.3 man pages
cp -p doc/doxygen/man/man3/wayland-{client,client-core,server,server-core,util}.h.3 \
	doc/doxygen/man/man3/wayland-{client,server,shm,util}.c.3 $RPM_BUILD_ROOT%{_mandir}/man3
%endif

# obsoleted by pkg-config
%{__rm} $RPM_BUILD_ROOT%{_libdir}/libwayland-*.la
%if %{with apidocs}
# packaged as %doc in -devel
%{__rm} -r $RPM_BUILD_ROOT%{_docdir}/wayland
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc COPYING README TODO
%attr(755,root,root) %{_libdir}/libwayland-client.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libwayland-client.so.0
%attr(755,root,root) %{_libdir}/libwayland-cursor.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libwayland-cursor.so.0
%attr(755,root,root) %{_libdir}/libwayland-server.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libwayland-server.so.0

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/wayland-scanner
%attr(755,root,root) %{_libdir}/libwayland-client.so
%attr(755,root,root) %{_libdir}/libwayland-cursor.so
%attr(755,root,root) %{_libdir}/libwayland-server.so
%{_includedir}/wayland-*.h
%dir %{_datadir}/wayland
%{_datadir}/wayland/wayland.dtd
%{_datadir}/wayland/wayland.xml
%{_datadir}/wayland/wayland-scanner.mk
%{_pkgconfigdir}/wayland-client.pc
%{_pkgconfigdir}/wayland-cursor.pc
%{_pkgconfigdir}/wayland-scanner.pc
%{_pkgconfigdir}/wayland-server.pc
%{_aclocaldir}/wayland-scanner.m4
%if %{with apidocs}
%{_mandir}/man3/wayland-*.c.3*
%{_mandir}/man3/wayland-*.h.3*
%{_mandir}/man3/wl_*.3*
%endif

%if %{with static_libs}
%files static
%defattr(644,root,root,755)
%{_libdir}/libwayland-client.a
%{_libdir}/libwayland-cursor.a
%{_libdir}/libwayland-server.a
%endif

%if %{with apidocs}
%files apidocs
%defattr(644,root,root,755)
%doc doc/publican/Wayland/en-US/html/*
%endif
%changelog
* Sun Nov 26 2017 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/wayland.git;a=log;h=auto/th/wayland-1.14.0-1

* Sun Nov 26 2017 Jakub Bogusz <qboosh@pld-linux.org> 545c2aa
- updated to 1.14.0

* Wed May 24 2017 Jakub Bogusz <qboosh@pld-linux.org> 5d06faa
- updated to 1.13.0
- added missing patch (generate missing man page)

* Tue Apr 04 2017 Marcin Krol <hawk@tld-linux.org> ed13418
- fix building without apidocs (documentation is disabled too so there
  are no man dirs)

* Sat Jan 14 2017 Jakub Bogusz <qboosh@pld-linux.org> 5f1528e
- updated to 1.12.0

* Sat Jul 02 2016 Jakub Bogusz <qboosh@pld-linux.org> 6a832ef
- updated to 1.11.0

* Sun Mar 06 2016 Jakub Bogusz <qboosh@pld-linux.org> 1cdf566
- updated to 1.10.0

* Mon Sep 28 2015 Jakub Bogusz <qboosh@pld-linux.org> 4645588
- updated to 1.9.0

* Thu Jul 02 2015 Elan Ruusamäe <glen@delfi.ee> 74a7acf
- noarch apidocs

* Thu Jun 18 2015 Jakub Bogusz <qboosh@pld-linux.org> 0379b85
- updated to 1.8.1

* Thu Feb 26 2015 Jakub Bogusz <qboosh@pld-linux.org> 73f3d2c
- updated to 1.7.0
- removed outdated publican patch

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> b04d7b1
- x32 rebuild
- release 2 (by relup.sh)

* Sun Feb 01 2015 Jan Rękorajski <baggins@pld-linux.org> 1f87db9
- up to 1.6.1

* Sat Dec 06 2014 Arkadiusz Miśkiewicz <arekm@maven.pl> 9af9de5
- libffi rebuild
- release 3 (by relup.sh)

* Sat Oct 04 2014 Jakub Bogusz <qboosh@pld-linux.org> 4dab03e
- minimal expat version

* Thu Sep 25 2014 Łukasz Kieś <kiesiu@pld-linux.org> ed71d02
- regenerate doxygen man files also

* Thu Sep 25 2014 Łukasz Kieś <kiesiu@pld-linux.org> 11e282e
- updated to 1.6.0

* Sat May 24 2014 Jakub Bogusz <qboosh@pld-linux.org> dbb3e8d
- updated to 1.5.0

* Sun Jan 26 2014 Jakub Bogusz <qboosh@pld-linux.org> d5e4471
- updated to 1.4.0

* Tue Dec 03 2013 Jakub Bogusz <qboosh@pld-linux.org> 7f5862a
- updated to 1.3.0 (1.2.x left on wayland-1.2 branch)

* Wed Sep 25 2013 Jakub Bogusz <qboosh@pld-linux.org> 3fea358
- updated to 1.2.1 (note: API changes, Mesa 9.2 requires patching)
- added publican patch

